Flask Method Config Globals - flarchitect
Description: Global < Global Method< Model < Model Method Global Method These values are defined in the Flask config, but are constrained to specific http methods. They should always be uppercase, They should a...

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Flask Method Config Globals

> Global < Global Method < Model < Model Method

Global Method

These values are defined in the Flask config, but are constrained to specific http methods.

- They should always be uppercase

- They should always start with `API_{method}_`

Values defined here will apply globally per method unless a more specific value is defined, they overwrite the global value if they are defined.

Will be overridden by value types; Global Method, Model, Model Method.

Overrides Global

## Example

    class Config():

        API_POST_RATE_LIMIT = "1 per minute"
        API_GET_RATE_LIMIT = "2 per minute"
        API_PUT_RATE_LIMIT = "3 per minute"